from extras.plugins import PluginMenuItem

menu_items = (
    PluginMenuItem(
        link='plugins:inventory_monitor:probe_list',
        link_text='Probe'
    ),
    PluginMenuItem(
        link='plugins:inventory_monitor:contractor_list',
        link_text='Contractors'
    ),
    PluginMenuItem(
        link='plugins:inventory_monitor:contract_list',
        link_text='Contracts'
    ),
    PluginMenuItem(
        link='plugins:inventory_monitor:invoice_list',
        link_text='Invoices'
    ),
)
